@@ -1,4 +1,5 @@
-/*  SCCS @(#)agsurv3.c	5.3 10/27/98
+/*  SCCS @(#)agsurv3.c	5.4 02/09/00
+/*
 ** Create the cohort survival curve(s) for a set of subjects.
 **
 **   This is similar in output to pyears3.  However, the hard part now is
@@ -75,25 +76,24 @@ void agsurv3(int   *sn,    int   *snvar,    int   *sncurve,
 	     double *cy,    double *cx,       double *ssurv,
 	     double *varh,  double *sused,    int   *smethod)
 {
-
     register int i,j,k,l;
     double *start, *stop, *event;
     int cn;
     int npt,
 	nvar2,
 	method;
-    int kk=1, psave; /*-Wall*/
+    int kk, psave;
     int itime;
     int person;
     int deaths, nrisk;
     int need;
     double *a, *a2;
-    double weight=1, /*-Wall*/
+    double weight,
 	   e_denom,
 	   denom;
     double inc,
 	   sumt,
-	   km=1; /*-Wall*/
+	   km;
     double temp,
 	   downwt,
 	   d2;
@@ -101,7 +101,6 @@ void agsurv3(int   *sn,    int   *snvar,    int   *sncurve,
 	   varhaz;
     double **oldx;
 
-    a=0;a2=0; oldx=0; /*-Wall*/
 
     n = *sn;  nvar = *snvar;
     cn = *scn; npt = *snpt;
@@ -214,7 +213,6 @@ void agsurv3(int   *sn,    int   *snvar,    int   *sncurve,
 		/*
 		** kalbfleisch estimator requires iteration;
 		*/
-		/* surely a bug: if (deaths = nrisk) km=0; */
 		if (deaths == nrisk) km=0;
 		else if (deaths ==1) {
 		    km = pow(1- score[kk]/denom, 1/score[kk]);
